summaryrefslogtreecommitdiff
path: root/src/inputprocessor.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/inputprocessor.cc')
-rw-r--r--src/inputprocessor.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/inputprocessor.cc b/src/inputprocessor.cc
index cbb74ad..a16115c 100644
--- a/src/inputprocessor.cc
+++ b/src/inputprocessor.cc
@@ -353,7 +353,7 @@ bool InputProcessor::processChoke(event_t& event,
if(event_sample.instrument_id == instrument_id /*&&
event_sample.rampdown_count == -1*/) // Only if not already ramping.
{
// Fixed group rampdown time of 68ms, independent of samplerate
// quick hack: all "Only if not already ramping" must be disabled for hi-hat pedal to work
if(event.offset >= 1000000) // quick hack: added 1000000 to offset to transport hi-hat controller value
@@ -364,7 +364,7 @@ if(event.offset >= 1000000) // quick hack: added 1000000 to offset to transport
}
else
{
- applyChoke(settings, event_sample, 450, event.offset);
+ applyChoke(settings, event_sample, 180, event.offset);
}
}
}
@@ -353,7 +353,7 @@ bool InputProcessor::processChoke(event_t& event,
event_sample.rampdown_count == -1*/) // Only if not already ramping.
{
- // Fixed group rampdown time of 68ms, independent of samplerate
+ // Fixed group rampdown time of 180ms, independent of samplerate
// quick hack: all "Only if not already ramping" must be disabled for hi-hat pedal to work
if(event.offset >= 1000000) // quick hack: added 1000000 to offset to transport hi-hat controller value